@@ -9,11 +9,10 @@ from pystan._compat import PY2, string_types, implements_to_string
 from collections import OrderedDict
 if PY2:
     from collections import Callable, Iterable
-    import md5 as hashlib
 else:
     from collections.abc import Callable, Iterable
-    import hashlib
 import datetime
+import hashlib
 import importlib
 import imp
 import io
@@ -245,13 +244,14 @@ class StanModel:
             s = template.safe_substitute(model_cppname=self.model_cppname)
             outfile.write(s)
 
+        extra_compile_args = ['-O3', '-ftemplate-depth-256']
         extension = Extension(name=module_name,
                               language="c++",
                               sources=[pyx_file],
                               include_dirs=include_dirs,
                               library_dirs=library_dirs,
                               libraries=libraries,
-                              extra_compile_args=['-O3'])
+                              extra_compile_args=extra_compile_args)
 
         cython_include_dirs = ['.', pystan_dir]
         build_extension = _get_build_extension()
@@ -350,7 +350,7 @@ class StanModel:
             names are the keys and the values are their associated values.
             Stan only accepts certain kinds of values; see Notes.
 
-        seed : int, optional
+        seed : int or np.random.RandomState, optional
             The seed, a positive integer for random number generation. Only
             one seed is needed when multiple chains are used, as the other
             chain's seeds are generated from the first chain's to prevent
@@ -447,9 +447,7 @@ class StanModel:
                 not isinstance(init, string_types):
             raise ValueError("Wrong specification of initial values.")
 
-        if seed is None:
-            seed = random.randint(0, MAX_UINT)
-        seed = int(seed)
+        seed = pystan.misc._check_seed(seed)
 
         stan_args = dict(init=init,
                          seed=seed,
@@ -502,7 +500,7 @@ class StanModel:
         thin : int, 1 by default
             Positive integer specifying the period for saving samples.
 
-        seed : int, optional
+        seed : int or np.random.RandomState, optional
             The seed, a positive integer for random number generation. Only
             one seed is needed when multiple chains are used, as the other
             chain's seeds are generated from the first chain's to prevent
@@ -636,10 +634,6 @@ class StanModel:
             raise ValueError("The number of chains is less than one; sampling"
                              "not done.")
 
-        if seed is None:
-            seed = random.randint(0, MAX_UINT)
-        seed = int(seed)
-
         args_list = pystan.misc._config_argss(chains=chains, iter=iter,
                                               warmup=warmup, thin=thin,
                                               init=init, seed=seed, sample_file=sample_file,
@@ -674,12 +668,8 @@ class StanModel:
         inits_used = pystan.misc._organize_inits([s['inits'] for s in samples],
                                                  m_pars, p_dims)
 
-        # test_gradient mode: don't sample
-        if samples[0]['test_grad']:
-            fit.sim = {'num_failed': [s['num_failed'] for s in samples]}
-            return fit
-
-        perm_lst = [np.random.permutation(n_kept) for _ in range(chains)]
+        random_state = np.random.RandomState(args_list[0]['seed'])
+        perm_lst = [random_state.permutation(n_kept) for _ in range(chains)]
         fnames_oi = fit._get_param_fnames_oi()
         n_flatnames = len(fnames_oi)
         fit.sim = {'samples': samples,
@@ -698,7 +688,7 @@ class StanModel:
         fit.model_name = self.model_name
         fit.model_pars = m_pars
         fit.par_dims = p_dims
-        fit.mode = 0
+        fit.mode = 0 if not kwargs.get('test_grad') else 1
         fit.inits = inits_used
         fit.stan_args = args_list
         fit.stanmodel = self
