@@ -26,5 +26,8 @@
 #include <stan/agrad/rev/matrix/trace_quad_form.hpp>
 #include <stan/agrad/rev/matrix/trace_gen_quad_form.hpp>
 #include <stan/agrad/rev/matrix/crossprod.hpp>
+#include <stan/agrad/rev/matrix/softmax.hpp>
+#include <stan/agrad/rev/matrix/log_softmax.hpp>
+#include <stan/agrad/rev/matrix/log_sum_exp.hpp>
 
 #endif
