@@ -3,9 +3,17 @@
 #include <boost/random/mersenne_twister.hpp>
 #include<boost/math/distributions.hpp>
 
-TEST(ProbDistributionsLogistic, random) {
+TEST(ProbDistributionsLogistic, error_check) {
   boost::random::mt19937 rng;
   EXPECT_NO_THROW(stan::prob::logistic_rng(4.0,3.0,rng));
+
+  EXPECT_THROW(stan::prob::logistic_rng(4.0,-3.0,rng),std::domain_error);
+  EXPECT_THROW(stan::prob::logistic_rng(4.0,stan::math::positive_infinity(),
+                                        rng),
+               std::domain_error);
+  EXPECT_THROW(stan::prob::logistic_rng(stan::math::positive_infinity(),3,
+                                        rng),
+               std::domain_error);
 }
 
 TEST(ProbDistributionsLogistic, chiSquareGoodnessFitTest) {
